pub struct Web3Signer {
pub client: ReqwestClient,
pub address: Address,
}Expand description
A signer that sends an RPC request to sign a transaction remotely
Implements eth_signTransaction method of Consensys Web3 Signer
Reference: https://docs.web3signer.consensys.io/reference/api/json-rpc#eth_signtransaction
Fields
client: ReqwestClientClient used to send an RPC request
address: AddressAddress of the account that intends to sign a transaction.
It must match the from field in the transaction.
Implementations